@@ -14,17 +14,19 @@ __author__ = 'Dungntc'
 @pytest.fixture(scope='function', autouse=True)
 def create_test_cycle_after_each_test_function(request):
     docstring = request._pyfuncitem._obj.__doc__
-    print(docstring)
     function_name = request._pyfuncitem.name
     test_id = f'{request._pyfuncitem.name}-{request._pyfuncitem.fspath}'
     if docstring and '::JIRA' in docstring:
+        # create test_case from docstring if exits
         test_case = TestCaseService.create_test_case_from_docstring(
             docstring=docstring,
             function_name=function_name,
             test_id=test_id)
     else:
+        # use test_case created before by decorator
         test_case = TestCaseService.find_test_case(test_id)
-
+    # file = open('out.txt', 'a')
+    # print(docstring, file=file)
     if test_case:
         yield
         TestCycleService.create_test_cycle(test_case.test_name, request.node.result)
